@@ -5,43 +5,51 @@
 
 struct my_struct {
     int id;                    /* key */
-    char name[10];             
+    char name[10];
     UT_hash_handle hh;         /* makes this structure hashable */
 };
 
 struct my_struct *users = NULL;
 
-void add_user(int user_id, char *name) {
+void add_user(int user_id, char *name)
+{
     struct my_struct *s;
 
-    s = (struct my_struct*)malloc(sizeof(struct my_struct));
-    s->id = user_id;
+    HASH_FIND_INT(users, &user_id, s);  /* id already in the hash? */
+    if (s==NULL) {
+        s = (struct my_struct*)malloc(sizeof(struct my_struct));
+        s->id = user_id;
+        HASH_ADD_INT( users, id, s );  /* id: name of key field */
+    }
     strcpy(s->name, name);
-    HASH_ADD_INT( users, id, s );  /* id: name of key field */
 }
 
-struct my_struct *find_user(int user_id) {
+struct my_struct *find_user(int user_id)
+{
     struct my_struct *s;
 
     HASH_FIND_INT( users, &user_id, s );  /* s: output pointer */
     return s;
 }
 
-void delete_user(struct my_struct *user) {
+void delete_user(struct my_struct *user)
+{
     HASH_DEL( users, user);  /* user: pointer to deletee */
     free(user);
 }
 
-void delete_all() {
-  struct my_struct *current_user, *tmp; 
+void delete_all()
+{
+    struct my_struct *current_user, *tmp;
 
-  HASH_ITER(hh, users, current_user, tmp) {
-    HASH_DEL(users,current_user);  /* delete it (users advances to next) */
-    free(current_user);            /* free it */
-  } 
+    HASH_ITER(hh, users, current_user, tmp) {
+        HASH_DEL(users,current_user);  /* delete it (users advances to next) */
+        free(current_user);            /* free it */
+    }
 }
 
-void print_users() {
+void print_users()
+{
     struct my_struct *s;
 
     for(s=users; s != NULL; s=(struct my_struct*)(s->hh.next)) {
@@ -49,37 +57,44 @@ void print_users() {
     }
 }
 
-int name_sort(struct my_struct *a, struct my_struct *b) {
+int name_sort(struct my_struct *a, struct my_struct *b)
+{
     return strcmp(a->name,b->name);
 }
 
-int id_sort(struct my_struct *a, struct my_struct *b) {
+int id_sort(struct my_struct *a, struct my_struct *b)
+{
     return (a->id - b->id);
 }
 
-void sort_by_name() {
+void sort_by_name()
+{
     HASH_SORT(users, name_sort);
 }
 
-void sort_by_id() {
+void sort_by_id()
+{
     HASH_SORT(users, id_sort);
 }
 
-int main(int argc, char *argv[]) {
+int main(int argc, char *argv[])
+{
     char in[10];
-    int id=1;
+    int id=1, running=1;
     struct my_struct *s;
     unsigned num_users;
 
-    while (1) {
-        printf("1. add user\n");
-        printf("2. find user\n");
-        printf("3. delete user\n");
-        printf("4. delete all users\n");
-        printf("5. sort items by name\n");
-        printf("6. sort items by id\n");
-        printf("7. print users\n");
-        printf("8. count users\n");
+    while (running) {
+        printf(" 1. add user\n");
+        printf(" 2. add/rename user by id\n");
+        printf(" 3. find user\n");
+        printf(" 4. delete user\n");
+        printf(" 5. delete all users\n");
+        printf(" 6. sort items by name\n");
+        printf(" 7. sort items by id\n");
+        printf(" 8. print users\n");
+        printf(" 9. count users\n");
+        printf("10. quit\n");
         gets(in);
         switch(atoi(in)) {
             case 1:
@@ -88,31 +103,47 @@ int main(int argc, char *argv[]) {
                 break;
             case 2:
                 printf("id?\n");
-                s = find_user(atoi(gets(in)));
-                printf("user: %s\n", s ? s->name : "unknown");
+                gets(in);
+                id = atoi(in);
+                printf("name?\n");
+                add_user(id, gets(in));
                 break;
             case 3:
                 printf("id?\n");
                 s = find_user(atoi(gets(in)));
-                if (s) delete_user(s);
-                else printf("id unknown\n");
+                printf("user: %s\n", s ? s->name : "unknown");
                 break;
             case 4:
-                delete_all();
+                printf("id?\n");
+                s = find_user(atoi(gets(in)));
+                if (s) {
+                    delete_user(s);
+                } else {
+                    printf("id unknown\n");
+                }
                 break;
             case 5:
-                sort_by_name();
+                delete_all();
                 break;
             case 6:
-                sort_by_id();
+                sort_by_name();
                 break;
             case 7:
-                print_users();
+                sort_by_id();
                 break;
             case 8:
+                print_users();
+                break;
+            case 9:
                 num_users=HASH_COUNT(users);
                 printf("there are %u users\n", num_users);
                 break;
+            case 10:
+                running=0;
+                break;
         }
     }
+
+    delete_all();  /* free any structures */
+    return 0;
 }
