@@ -8,27 +8,33 @@ typedef struct person_t {
     UT_hash_handle hh;
 } person_t;
 
-int main(int argc, char*argv[]) {
+int main(int argc, char*argv[])
+{
     person_t *people=NULL, *person;
-    char **name;
-    char *names[] = { "bob", "jack", "gary", "ty", "bo", "phil", "art", 
-                      "gil", "buck", "ted", NULL };
+    const char **name;
+    const char * names[] = { "bob", "jack", "gary", "ty", "bo", "phil", "art",
+                             "gil", "buck", "ted", NULL
+                           };
     int id=0;
 
-    for(name=names; *name; name++) {
-        if ( (person = (person_t*)malloc(sizeof(person_t))) == NULL) exit(-1);
-        strncpy(person->first_name, *name,10);
+    for(name=names; *name != NULL; name++) {
+        person = (person_t*)malloc(sizeof(person_t));
+        if (person == NULL) {
+            exit(-1);
+        }
+        strncpy(person->first_name, *name,10UL);
         person->id = id++;
         HASH_ADD_STR(people,first_name,person);
         printf("added %s (id %d)\n", person->first_name, person->id);
     }
 
-    for(name=names; *name; name++) {
+    for(name=names; *name != NULL; name++) {
         HASH_FIND_STR(people,*name,person);
-        if (person) 
+        if (person != NULL) {
             printf("found %s (id %d)\n", person->first_name, person->id);
-        else 
+        } else {
             printf("failed to find %s\n", *name);
+        }
     }
-   return 0;
+    return 0;
 }
