@@ -5,24 +5,36 @@
 
 struct my_struct {
     char name[10];             /* key */
-    int id;                    
+    int id;
     UT_hash_handle hh;         /* makes this structure hashable */
 };
 
 
-int main(int argc, char *argv[]) {
+int main(int argc, char *argv[])
+{
     const char **n, *names[] = { "joe", "bob", "betty", NULL };
-    struct my_struct *s, *users = NULL;
+    struct my_struct *s, *tmp, *users = NULL;
     int i=0;
 
     for (n = names; *n != NULL; n++) {
         s = (struct my_struct*)malloc(sizeof(struct my_struct));
-        strncpy(s->name, *n,10);
+        if (s == NULL) {
+            exit(-1);
+        }
+        strncpy(s->name, *n,10UL);
         s->id = i++;
-        HASH_ADD_STR( users, name, s );  
+        HASH_ADD_STR( users, name, s );
     }
 
     HASH_FIND_STR( users, "betty", s);
-    if (s) printf("betty's id is %d\n", s->id);
-   return 0;
+    if (s != NULL) {
+        printf("betty's id is %d\n", s->id);
+    }
+
+    /* free the hash table contents */
+    HASH_ITER(hh, users, s, tmp) {
+        HASH_DEL(users, s);
+        free(s);
+    }
+    return 0;
 }
