@@ -10,35 +10,46 @@ typedef struct el {
     struct el *next, *prev;
 } el;
 
-int namecmp(el *a, el *b) {
+static int namecmp(void *_a, void *_b)
+{
+    el *a = (el*)_a;
+    el *b = (el*)_b;
     return strcmp(a->bname,b->bname);
 }
 
-el *head = NULL;
-
-int main(int argc, char *argv[]) {
+int main(int argc, char *argv[])
+{
     el *name, *tmp;
+    el *head = NULL;
 
     char linebuf[BUFLEN];
     FILE *file;
 
-    if ( (file = fopen( "test11.dat", "r" )) == NULL ) {
-        perror("can't open: "); 
+    file = fopen( "test11.dat", "r" );
+    if (file == NULL) {
+        perror("can't open: ");
         exit(-1);
     }
 
     while (fgets(linebuf,BUFLEN,file) != NULL) {
-        if ( (name = (el*)malloc(sizeof(el))) == NULL) exit(-1);
-        strncpy(name->bname,linebuf,BUFLEN);
+        name = (el*)malloc(sizeof(el));
+        if (name == NULL) {
+            exit(-1);
+        }
+        strncpy(name->bname,linebuf,sizeof(name->bname));
         DL_APPEND(head, name);
     }
     DL_SORT(head, namecmp);
-    DL_FOREACH(head,tmp) printf("%s", tmp->bname);
+    DL_FOREACH(head,tmp) {
+        printf("%s", tmp->bname);
+    }
 
     /* now delete the list head */
     printf("deleting head %shead->prev: %s", head->bname, head->prev->bname);
     DL_DELETE(head,head);
-    DL_FOREACH(head,tmp) printf("%s", tmp->bname);
+    DL_FOREACH(head,tmp) {
+        printf("%s", tmp->bname);
+    }
 
     fclose(file);
 
